@@ -1,8 +1,11 @@
 from PyOfficeRobot.core.WeChatType import WeChat
+from PyOfficeRobot.lib.CONST import ACT_TYPE
+from PyOfficeRobot.lib.dec.act_dec import act_info
 
 wx = WeChat()
 
 
+@act_info(ACT_TYPE.MESSAGE)
 def send_message(who, message):
     """
     给指定人，发送一条消息
@@ -10,6 +13,7 @@ def send_message(who, message):
     :param message:
     :return:
     """
+
     # 获取会话列表
     wx.GetSessionList()
     wx.ChatWith(who)  # 打开`文件传输助手`聊天窗口
